@@ -194,6 +194,7 @@ class TrackingFileManager
         }
     }
 
+    @SuppressWarnings( { "checkstyle:magicnumber" } )
     private FileLock lock( FileChannel channel, long size, boolean shared )
         throws IOException
     {
@@ -210,7 +211,7 @@ class TrackingFileManager
             {
                 if ( attempts <= 0 )
                 {
-                    throw (IOException) new IOException().initCause( e );
+                    throw new IOException( e );
                 }
                 try
                 {
