@@ -8,9 +8,9 @@ package org.eclipse.aether.internal.impl.collect;
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  *  http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -81,8 +81,12 @@ public class DefaultDependencyCollector
 
     private static final String CONFIG_PROP_MAX_EXCEPTIONS = "aether.dependencyCollector.maxExceptions";
 
+    private static final int CONFIG_PROP_MAX_EXCEPTIONS_DEFAULT = 50;
+
     private static final String CONFIG_PROP_MAX_CYCLES = "aether.dependencyCollector.maxCycles";
 
+    private static final int CONFIG_PROP_MAX_CYCLES_DEFAULT = 10;
+
     private static final Logger LOGGER = LoggerFactory.getLogger( DefaultDependencyCollector.class );
 
     private RemoteRepositoryManager remoteRepositoryManager;
@@ -115,7 +119,8 @@ public class DefaultDependencyCollector
 
     public DefaultDependencyCollector setRemoteRepositoryManager( RemoteRepositoryManager remoteRepositoryManager )
     {
-        this.remoteRepositoryManager = requireNonNull( remoteRepositoryManager, "remote repository provider cannot be null" );
+        this.remoteRepositoryManager =
+                requireNonNull( remoteRepositoryManager, "remote repository provider cannot be null" );
         return this;
     }
 
@@ -127,10 +132,12 @@ public class DefaultDependencyCollector
 
     public DefaultDependencyCollector setVersionRangeResolver( VersionRangeResolver versionRangeResolver )
     {
-        this.versionRangeResolver = requireNonNull( versionRangeResolver, "version range resolver cannot be null" );
+        this.versionRangeResolver =
+                requireNonNull( versionRangeResolver, "version range resolver cannot be null" );
         return this;
     }
 
+    @SuppressWarnings( "checkstyle:methodlength" )
     public CollectResult collectDependencies( RepositorySystemSession session, CollectRequest request )
         throws DependencyCollectionException
     {
@@ -312,7 +319,7 @@ public class DefaultDependencyCollector
         else
         {
             int initialCapacity = dominant.size() + recessive.size();
-            result = new ArrayList<Dependency>( initialCapacity );
+            result = new ArrayList<>( initialCapacity );
             Collection<String> ids = new HashSet<String>( initialCapacity, 1.0f );
             for ( Dependency dependency : dominant )
             {
@@ -335,6 +342,7 @@ public class DefaultDependencyCollector
         return a.getGroupId() + ':' + a.getArtifactId() + ':' + a.getClassifier() + ':' + a.getExtension();
     }
 
+    @SuppressWarnings( "checkstyle:parameternumber" )
     private void process( final Args args, Results results, List<Dependency> dependencies,
                           List<RemoteRepository> repositories, DependencySelector depSelector,
                           DependencyManager depManager, DependencyTraverser depTraverser, VersionFilter verFilter )
@@ -346,6 +354,7 @@ public class DefaultDependencyCollector
         }
     }
 
+    @SuppressWarnings( "checkstyle:parameternumber" )
     private void processDependency( Args args, Results results, List<RemoteRepository> repositories,
                                     DependencySelector depSelector, DependencyManager depManager,
                                     DependencyTraverser depTraverser, VersionFilter verFilter, Dependency dependency )
@@ -357,6 +366,7 @@ public class DefaultDependencyCollector
                            relocations, disableVersionManagement );
     }
 
+    @SuppressWarnings( "checkstyle:parameternumber" )
     private void processDependency( Args args, Results results, List<RemoteRepository> repositories,
                                     DependencySelector depSelector, DependencyManager depManager,
                                     DependencyTraverser depTraverser, VersionFilter verFilter, Dependency dependency,
@@ -466,6 +476,7 @@ public class DefaultDependencyCollector
         }
     }
 
+    @SuppressWarnings( "checkstyle:parameternumber" )
     private void doRecurse( Args args, Results results, List<RemoteRepository> repositories,
                             DependencySelector depSelector, DependencyManager depManager,
                             DependencyTraverser depTraverser, VersionFilter verFilter, Dependency d,
@@ -546,6 +557,7 @@ public class DefaultDependencyCollector
         return descriptorResult;
     }
 
+    @SuppressWarnings( "checkstyle:parameternumber" )
     private static DefaultDependencyNode createDependencyNode( List<Artifact> relocations,
                                                                PremanagedDependency preManaged,
                                                                VersionRangeResult rangeResult, Version version,
@@ -725,8 +737,11 @@ public class DefaultDependencyCollector
         Results( CollectResult result, RepositorySystemSession session )
         {
             this.result = result;
-            this.maxExceptions = ConfigUtils.getInteger( session, 50, CONFIG_PROP_MAX_EXCEPTIONS );
-            this.maxCycles = ConfigUtils.getInteger( session, 10, CONFIG_PROP_MAX_CYCLES );
+
+            maxExceptions =
+                    ConfigUtils.getInteger( session, CONFIG_PROP_MAX_EXCEPTIONS_DEFAULT, CONFIG_PROP_MAX_EXCEPTIONS );
+
+            maxCycles = ConfigUtils.getInteger( session, CONFIG_PROP_MAX_CYCLES_DEFAULT, CONFIG_PROP_MAX_CYCLES );
         }
 
         public void addException( Dependency dependency, Exception e, NodeStack nodes )
@@ -794,6 +809,7 @@ public class DefaultDependencyCollector
 
         final boolean premanagedState;
 
+        @SuppressWarnings( "checkstyle:parameternumber" )
         PremanagedDependency( String premanagedVersion, String premanagedScope, Boolean premanagedOptional,
                               Collection<Exclusion> premanagedExclusions, Map<String, String> premanagedProperties,
                               int managedBits, Dependency managedDependency, boolean premanagedState )
@@ -803,12 +819,12 @@ public class DefaultDependencyCollector
             this.premanagedOptional = premanagedOptional;
             this.premanagedExclusions =
                 premanagedExclusions != null
-                    ? Collections.unmodifiableCollection( new ArrayList<Exclusion>( premanagedExclusions ) )
+                    ? Collections.unmodifiableCollection( new ArrayList<>( premanagedExclusions ) )
                     : null;
 
             this.premanagedProperties =
                 premanagedProperties != null
-                    ? Collections.unmodifiableMap( new HashMap<String, String>( premanagedProperties ) )
+                    ? Collections.unmodifiableMap( new HashMap<>( premanagedProperties ) )
                     : null;
 
             this.managedBits = managedBits;
